/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.isobus.model;

/**
 * Describes the data types of the ISO-17783-10 TIM element in the binary file 
 * @author Gerben Feenstra
 */
public enum TimeFieldEnum implements XmlField {

    /** TIM A **/
    TIME_START_TIME("A", BinaryDataType.BIT32_UNSIGNED),   
    TIME_START_DATE("A", BinaryDataType.BIT16_UNSIGNED),
        
    /** TIM B **/
    TIME_STOP("B", BinaryDataType.BIT32_UNSIGNED),
    /** TIM C **/
    TIME_DURATION("C", BinaryDataType.BIT32_UNSIGNED),
    /** TIM D **/
    TIME_TYPE("D", BinaryDataType.BIT8_SIGNED);
    
    String xmlField = "";
    BinaryDataType dataType = null;
    
    TimeFieldEnum(String xmlField, BinaryDataType dataType) {
        this.xmlField = xmlField;
        this.dataType = dataType;
    }

    @Override
    public String getAttributeName() {
        return xmlField;
    }

    @Override
    public BinaryDataType getDataType() {
        return dataType;
    }
    
    public static String getXmlTagName(){
        return "TIM";
    }
}
